import React, { useState, useCallback } from 'react';
import { Upload, notification } from 'antd';
import { LoadingOutlined, PlusOutlined } from '@ant-design/icons';
import uploadFile from '@/utils/uploadFile';

export default (props) => {
  const [loading, setLoading] = useState(false);

  const handleChange = useCallback(
    ({ file }) => {
      switch (file.status) {
        case 'done':
          setLoading(false);
          props.onChange(file.response);
          break;
        case 'error':
          setLoading(false);
          notification.error({ message: file.error });
          break;
        default:
          setLoading(true);
      }
    },
    [props],
  );

  return (
    <Upload
      accept=".png, .jpg, .jpeg, .gif"
      listType="picture-card"
      className="avatar-uploader"
      showUploadList={false}
      customRequest={uploadFile}
      onChange={handleChange}
    >
      {props.value ? (
        <img src={props.value} width="100%" alt="" />
      ) : (
        <div>
          {loading ? <LoadingOutlined /> : <PlusOutlined />}
          <div style={{ marginTop: 8 }}>上传</div>
        </div>
      )}
    </Upload>
  );
};
