import { notification } from 'antd'
import { queryCurrent, query as queryUsers, queryRoles } from '@/services/user';
import { setAuthority } from '@/utils/authority';

const UserModel = {
  namespace: 'user',
  state: {
    currentUser: {},
    menus: [],
    roles: [],
  },
  effects: {
    *fetch(_, { call, put }) {
      const response = yield call(queryUsers);
      yield put({
        type: 'save',
        payload: response,
      });
    },

    *fetchCurrent(_, { call, put }) {
      try {
        const response = yield call(queryCurrent);
        yield put({
          type: 'saveCurrentUser',
          payload: response,
        });
      } catch (e) {
        //
      }
    },

    *fetchRoles(_, { call, put }) {
      try {
        const response = yield call(queryRoles);
        yield put({
          type: 'updateRoles',
          payload: response.records,
        });
      } catch (e) {
        notification.error({
          message: `获取角色失败: ${e.message}`
        })
      }
    }
  },
  reducers: {
    saveCurrentUser(state, action) {
      const { user, menus, roles } = action.payload || {};

      setAuthority(roles.map((x) => `${x.roleId}`));

      return { ...state, currentUser: user, menus };
    },

    updateRoles(state, { payload }) {
      return { ...state, roles: payload || [] };
    },

    changeNotifyCount(
      state = {
        currentUser: {},
      },
      action,
    ) {
      return {
        ...state,
        currentUser: {
          ...state.currentUser,
          notifyCount: action.payload.totalCount,
          unreadCount: action.payload.unreadCount,
        },
      };
    },
  },
};
export default UserModel;
