import React, { useState, useEffect } from 'react'
import { PageContainer } from '@ant-design/pro-layout';
import { notification, Tabs } from 'antd';
import Container from '@/components/Container';
import request from '@/utils/request';
import UserForm from './components/User'
import UserRole from './components/Role'

const { TabPane } = Tabs;

export default (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [user, setUser] = useState({});

  const handleRoleSubmit = (roleList) => {
    setUser({
      ...user,
      roleList,
    })
  }

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/user/${id}`)
        .then((res) => {
          setUser(res);
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [id]);

  return (
    <PageContainer>
    <Container>
      <Tabs>
        <TabPane tab="基本信息" key="1">
          <Container loading={loading}>
            <UserForm user={user} onChange={setUser} />
          </Container>
        </TabPane>
        <TabPane tab="角色设置" key="2">
          <Container>
            <UserRole user={user} onSubmit={handleRoleSubmit} />
          </Container>
        </TabPane>
      </Tabs>
    </Container>
    </PageContainer>
  )
}
